==> openshift-model-operator-6.3.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSRecordListFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DNSRecordListFluent<A extends DNSRecordListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,DNSRecord item);
  public A setToItems(Integer index,DNSRecord item);
  public A addToItems(io.fabric8.openshift.api.model.operator.v1.DNSRecord... items);
  public A addAllToItems(Collection<DNSRecord> items);
  public A removeFromItems(io.fabric8.openshift.api.model.operator.v1.DNSRecord... items);
  public A removeAllFromItems(Collection<DNSRecord> items);
  public A removeMatchingFromItems(Predicate<DNSRecordBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DNSRecord> getItems();
  public List<DNSRecord> buildItems();
  public DNSRecord buildItem(Integer index);
  public DNSRecord buildFirstItem();
  public DNSRecord buildLastItem();
  public DNSRecord buildMatchingItem(Predicate<DNSRecordBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DNSRecordBuilder> predicate);
  public A withItems(List<DNSRecord> items);
  public A withItems(io.fabric8.openshift.api.model.operator.v1.DNSRecord... items);
  public Boolean hasItems();
  public DNSRecordListFluent.ItemsNested<A> addNewItem();
  public DNSRecordListFluent.ItemsNested<A> addNewItemLike(DNSRecord item);
  public DNSRecordListFluent.ItemsNested<A> setNewItemLike(Integer index,DNSRecord item);
  public DNSRecordListFluent.ItemsNested<A> editItem(Integer index);
  public DNSRecordListFluent.ItemsNested<A> editFirstItem();
  public DNSRecordListFluent.ItemsNested<A> editLastItem();
  public DNSRecordListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSRecordBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,DNSRecordFluent<DNSRecordListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSRecordListFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DNSRecordListFluent<A extends DNSRecordListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,DNSRecord item);
  public A setToItems(int index,DNSRecord item);
  public A addToItems(io.fabric8.openshift.api.model.operator.v1.DNSRecord... items);
  public A addAllToItems(Collection<DNSRecord> items);
  public A removeFromItems(io.fabric8.openshift.api.model.operator.v1.DNSRecord... items);
  public A removeAllFromItems(Collection<DNSRecord> items);
  public A removeMatchingFromItems(Predicate<DNSRecordBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DNSRecord> getItems();
  public List<DNSRecord> buildItems();
  public DNSRecord buildItem(int index);
  public DNSRecord buildFirstItem();
  public DNSRecord buildLastItem();
  public DNSRecord buildMatchingItem(Predicate<DNSRecordBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DNSRecordBuilder> predicate);
  public A withItems(List<DNSRecord> items);
  public A withItems(io.fabric8.openshift.api.model.operator.v1.DNSRecord... items);
  public Boolean hasItems();
  public DNSRecordListFluent.ItemsNested<A> addNewItem();
  public DNSRecordListFluent.ItemsNested<A> addNewItemLike(DNSRecord item);
  public DNSRecordListFluent.ItemsNested<A> setNewItemLike(int index,DNSRecord item);
  public DNSRecordListFluent.ItemsNested<A> editItem(int index);
  public DNSRecordListFluent.ItemsNested<A> editFirstItem();
  public DNSRecordListFluent.ItemsNested<A> editLastItem();
  public DNSRecordListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSRecordBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,DNSRecordFluent<DNSRecordListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
